==> ircd-ratbox-1.4-1.tgz: ircd-ratbox-1.4-1/contrib/spy_admin_notice.c <==
/*
 *  ircd-ratbox: A slightly useful ircd.
 *  spy_admin_notice.c: Sends a notice when someone uses ADMIN.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: spy_admin_notice.c,v 1.9.4.3 2004/03/28 01:31:10 leeh Exp $
 */
#include "stdinc.h"
#include "modules.h"
#include "hook.h"
#include "client.h"
#include "ircd.h"
#include "send.h"

int show_admin(struct Client *);

void
_modinit(void)
{
	hook_add_hook("doing_admin", (hookfn) show_admin);
}

void
_moddeinit(void)
{
	hook_del_hook("doing_admin", (hookfn) show_admin);
}

const char *_version = "$Revision: 1.9.4.3 $";

int
show_admin(struct Client *source_p)
{
	sendto_realops_flags(UMODE_SPY, L_ALL,
			"admin requested by %s (%s@%s) [%s]",
			source_p->name, source_p->username,
			source_p->host, source_p->user->server);

	return 0;
}

==> ircd-ratbox-2.0.2.tgz: ircd-ratbox-2.0.2/contrib/spy_admin_notice.c <==
/*
 *  ircd-ratbox: A slightly useful ircd.
 *  spy_admin_notice.c: Sends a notice when someone uses ADMIN.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: spy_admin_notice.c,v 1.11 2004/03/07 16:46:38 leeh Exp $
 */
#include "stdinc.h"
#include "modules.h"
#include "hook.h"
#include "client.h"
#include "ircd.h"
#include "send.h"

int show_admin(struct hook_spy_data *);

mapi_hfn_list_av1 admin_hfnlist[] = {
	{"doing_admin", (hookfn) show_admin},
	{NULL, NULL}
};

DECLARE_MODULE_AV1(admin_spy, NULL, NULL, NULL, NULL, admin_hfnlist, "$Revision: 1.11 $");

int
show_admin(struct hook_spy_data *data)
{
	sendto_realops_flags(UMODE_SPY, L_ALL,
			     "admin requested by %s (%s@%s) [%s]",
			     data->source_p->name, data->source_p->username,
			     data->source_p->host, data->source_p->user->server);

	return 0;
}
